summaryrefslogtreecommitdiff
path: root/xstatic/pkg/jquery_ui/data/ui/jquery.ui.selectable.js
diff options
context:
space:
mode:
Diffstat (limited to 'xstatic/pkg/jquery_ui/data/ui/jquery.ui.selectable.js')
-rw-r--r--xstatic/pkg/jquery_ui/data/ui/jquery.ui.selectable.js8
1 files changed, 4 insertions, 4 deletions
diff --git a/xstatic/pkg/jquery_ui/data/ui/jquery.ui.selectable.js b/xstatic/pkg/jquery_ui/data/ui/jquery.ui.selectable.js
index 275021d..44c6e8c 100644
--- a/xstatic/pkg/jquery_ui/data/ui/jquery.ui.selectable.js
+++ b/xstatic/pkg/jquery_ui/data/ui/jquery.ui.selectable.js
@@ -1,7 +1,7 @@
/*
* jQuery UI Selectable 1.8.18
*
- * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2012, AUTHORS.txt (http://jqueryui.com/about)
* Dual licensed under the MIT or GPL Version 2 licenses.
* http://jquery.org/license
*
@@ -261,7 +261,7 @@ $.widget("ui.selectable", $.ui.mouse, {
});
$.extend($.ui.selectable, {
- version: "1.8.18"
+ version: "1.8.24"
});
})(jQuery);
@@ -1,7 +1,7 @@
-/*
- * jQuery UI Selectable 1.8.18
+/*!
+ * jQuery UI Selectable 1.8.24
*